torrentspy - get the latest news at TorrentFreak

Breaking

# Can The Pirate Bay Make a Comeback?

- On: 10/12/2014
- Comments: 0

Tag Page

# Popular Posts in torrentspy

# TorrentSpy Slapped with $110 Million Judgement

- By Ernesto
- on May 7, 2008
- C: 138

TorrentSpy has been ordered to pay a $110 million fine by a federal judge in Los Angeles. The BitTorrent site was found guilty on the charges of copyright infringement of several movie studios represented by the MPAA.

# TorrentSpy Shuts Down

- By Ernesto
- on March 27, 2008
- C: 119

A little over a year ago, TorrentSpy.com was still the most visited BitTorrent site, but times have changed. After an expensive two year battle with the MPAA, TorrentSpy decided to throw in the towel and the site has now shut down permanently.

# Filtering Torrents: The Pirate Bay vs. Torrentspy & Isohunt

- By Ernesto
- on July 22, 2007
- C: 118

Torrentspy and Isohunt announced that they will give content owners a "carte blanche" to remove torrents from their BitTorrent search engines last month. The perfect solution for content owners and site admins says Torrentspy - a nightmare according to The Pirate Bay.

# TorrentSpy Blocks Searches From US Visitors

- By Ernesto
- on August 27, 2007
- C: 72

Starting today, TorrentSpy blocks all searches from US visitors and redirects them to a privacy statement. TorrentSpy is caught up in a lawsuit in which the MPAA demands that TorrentSpy hands over all user info stored in "random access memory" (RAM).

# Recent Posts in torrentspy

# The Most Popular Torrent Sites Of The Last Five Years

- On: 22/08/2010
- Comments: 66

# MPAA’s Hacking Past Comes Back to Hunt

- On: 12/04/2009
- Comments: 43

# TorrentSpy, One Year After the Shutdown

- On: 24/03/2009
- Comments: 48

# TorrentSpy to Appeal in MPAA Court Case

- On: 04/02/2009
- Comments: 27

# EFF Supports TorrentSpy in Electronic Privacy Case

- On: 06/08/2008
- Comments: 22

# TorrentSpy Slapped with $110 Million Judgement

- On: 07/05/2008
- Comments: 138

# TorrentSpy Shuts Down

- On: 27/03/2008
- Comments: 119

# TorrentSpy Loses Case Against MPAA

- On: 18/12/2007
- Comments: 98

# Leading BitTorrent Admins Discuss The Future of BitTorrent

- On: 13/11/2007
- Comments: 46

# MPAA Not Done With TorrentSpy Yet

- On: 12/10/2007
- Comments: 50

# TorrentSpy Traffic Plunges After US Ban

- On: 06/10/2007
- Comments: 46

# TorrentSpy Blocks Searches From US Visitors

- On: 27/08/2007
- Comments: 72

## Sponsors

# Most Commented Posts

- Sony Movies Leak Online After Hack Attack 246
- Swedish Police Raid The Pirate Bay, Site Offline 0
- Luxury Watchmakers Target Pirate Smartwatch Faces 57
- Google Removes Pirate Bay Apps From Play Store 85
- ISPs Must Take Responsibility For Sony Movie Leaks, MP Says 126

# Popular Posts

- Which VPN Services Take Your Anonymity Seriously? 2014 Edition
- Top 10 Most Popular Torrent Sites of 2014
- Review: Is Your VPN Service Really Anonymous?
- 5 Ways To Download Torrents Anonymously
- How To Make VPNs Even More Secure